#!/bin/sh

#Copyright (C) 2006 - 2008 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or
#Modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details

. /opt/hinemos_agent/bin/hinemos_agent.cfg

if [ -f $HINEMOS_AGENT_PID ] ; then
	read AGENT_PID < $HINEMOS_AGENT_PID
	ps -p $AGENT_PID -f | grep $HINEMOS_AGENT_HOME > /dev/null && TMP=1
	if [ "$TMP" ] ; then
	        echo "Agent already started!"
        	exit 1
	fi
fi

nohup $JAVA_PROC -cp $HINEMOS_AGENT_HOME/lib/agent:$HINEMOS_AGENT_HOME/lib/agent/agent.jar:$HINEMOS_AGENT_HOME/lib/commons-logging-1.1.jar:$HINEMOS_AGENT_HOME/lib/javassist.jar:$HINEMOS_AGENT_HOME/lib/jboss-aop-jdk50.jar:$HINEMOS_AGENT_HOME/lib/jboss-messaging-client.jar:$HINEMOS_AGENT_HOME/lib/jboss-remoting.jar:$HINEMOS_AGENT_HOME/lib/jbossall-client.jar:$HINEMOS_AGENT_HOME/lib/log4j-1.2.14.jar:$HINEMOS_AGENT_HOME/lib/trove.jar:$HINEMOS_AGENT_HOME/lib/JobManagementEJB.jar:$HINEMOS_AGENT_HOME/lib/RepositoryEJB.jar:$HINEMOS_AGENT_HOME/lib/clustercontrol.jar:$HINEMOS_AGENT_HOME/lib/hinemos-commons.jar com.clustercontrol.agent.Agent $HINEMOS_AGENT_HOME/lib/agent/Agent.properties 2>> $HINEMOS_AGENT_HOME/bin/job_nohup.out &
echo $! > $HINEMOS_AGENT_PID  
echo "Agent started"
